package de.intevation.flys.artifacts;

import java.util.List;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import de.intevation.artifacts.ArtifactNamespaceContext;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.ProtocolUtils;
import de.intevation.artifactdatabase.state.Facet;
import de.intevation.artifactdatabase.state.Output;
import de.intevation.artifactdatabase.state.State;

import de.intevation.artifacts.common.utils.XMLUtils;
import de.intevation.artifacts.common.utils.XMLUtils.ElementCreator;


public abstract class StaticFLYSArtifact extends FLYSArtifact {

    private static final Logger logger =
        Logger.getLogger(StaticFLYSArtifact.class);


    @Override
    public Document describe(Document data, CallContext cc) {
        logger.debug("Describe artifact: " + identifier());

        Document desc = XMLUtils.newDocument();

        ElementCreator creator = new ElementCreator(
            desc,
            ArtifactNamespaceContext.NAMESPACE_URI,
            ArtifactNamespaceContext.NAMESPACE_PREFIX);

        Element root = ProtocolUtils.createRootNode(creator);
        desc.appendChild(root);

        ProtocolUtils.appendDescribeHeader(creator, root, identifier(), hash());
        root.appendChild(createOutputModes(cc, desc, creator));

        return desc;
    }


    protected Element createOutputModes(
        CallContext    cc,
        Document       doc,
        ElementCreator creator)
    {
        Element outs = ProtocolUtils.createArtNode(
            creator, "outputmodes", null, null);

        State state       = getCurrentState(cc);
        List<Output> list = state.getOutputs();

        if (list != null && list.size() > 0) {
            if (facets != null && facets.size() > 0) {
                List<Output> generated = generateOutputs(list, facets);

                logger.debug("Found " + facets.size() + " current facets.");
                if (!generated.isEmpty()) {
                    ProtocolUtils.appendOutputModes(
                        doc, outs, generated);
                }
            }
            else {
                logger.debug("No facets found for the current state.");
            }
        }

        return outs;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
